@@ -58,13 +58,11 @@ cgeneric_generic0 <-
 
     dotArgs <- list(...)
     if(is.null(dotArgs$debug)) {
-      debug <- FALSE
-    } else {
-      debug <- dotArgs$debug
+      dotArgs$debug <- FALSE
     }
 
     R <- upperPadding(R)
-    if(debug) {
+    if(dotArgs$debug) {
       print(str(R))
     }
 
@@ -72,47 +70,57 @@ cgeneric_generic0 <-
     stopifnot(n>0)
 
     if(scale) {
-      stopifnot(requireNamespace("INLA"))
-      Rs <- try(do.call(
-        what = "inla.scale.model.internal",
-        args = list(Q = R,
-                    constr = list(A = matrix(1, 1, n), e = 0))
-      ), silent = FALSE)
-      if(inherits(Rs, "try-error")) {
-        stop("Error trying to scale the model!")
+      vs <- "24.02.09"
+      inlaCheck <- packageCheck(
+        name = "INLA",
+        minimum_version = vs) >= vs
+      if(is.na(inlaCheck)) {
+        warning("Install INLA to fast and disconected graphs scaling!")
+        .gi <- function(m) {
+          s <- svd(R)
+          ip <- which(s$d>sqrt(.Machine$double.eps))
+          stopifnot(length(ip)==0)
+          return(s$v[, ip, drop = FALSE] %*% (
+                   (1/s$d[ip])*t(s$u[, ip, drop=FALSE])))
+        }
+        R <- Sparse(R * exp(mean(log(diag(.gi(R))))))
       } else {
-        if(debug) {
-          cat("Marginal var = ", Rs$var, "\n")
+        fns <- findGetFunction("inla.scale.model.internal", "INLA")
+        Rs <- try(fns(
+          Q = R,
+          constr = list(A = matrix(1, 1, n), e = 0)
+        ), silent = FALSE)
+        if(inherits(Rs, "try-error")) {
+          stop("Error trying to scale the model!")
+        } else {
+          if(dotArgs$debug) {
+            cat("Marginal var = ", Rs$var, "\n")
+          }
+          R <- Sparse(Rs$Q)
         }
-        R <- Sparse(Rs$Q)
       }
     }
-
     if(is.null(dotArgs$useINLAprecomp)) {
-      useINLAprecomp <- TRUE
-    } else {
-      useINLAprecomp <- dotArgs$useINLAprecomp
+      dotArgs$useINLAprecomp <- TRUE
     }
     INLAvcheck <- packageCheck("INLA", "25-10-28")
-    if(is.na(INLAvcheck) & useINLAprecomp) {
-      useINLAprecomp <- FALSE
+    if(is.na(INLAvcheck) & dotArgs$useINLAprecomp) {
+      dotArgs$useINLAprecomp <- FALSE
       warning("INLA version is old. Setting 'useINLAprecomp = FALSE'!")
     }
-    shlib <- cgeneric_shlib(
+    dotArgs$shlib <- cgeneric_shlib(
       package = "INLAtools",
-      useINLAprecomp = useINLAprecomp,
-      debug = debug)
+      useINLAprecomp = dotArgs$useINLAprecomp,
+      debug = dotArgs$debug)
 
     the_model <- do.call(
       what = "cgenericBuilder",
-      args = list(
+      args = c(list(
         model = "inla_cgeneric_generic0",
         n=as.integer(n),
         param=param,
-        Rgraph = R,
-        debug = debug,
-        shlib = shlib
-      )
+        Rgraph = R),
+        dotArgs)
     )
 
     if(constr) {
